@@ -745,7 +745,13 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
             if write_file:
                 writer = pd.ExcelWriter(local_root_directory + f'perf_dd_{me_strat_name}_{clean_title}.xlsx',
                                         engine='xlsxwriter')
-                data.to_excel(writer, sheet_name='kpi')
+                data.to_excel(writer, sheet_name='daily')
+                month_data=data.copy()
+
+                month_data['beginning_month'] = month_data['day'].index.day==1
+                month_data['ending_month'] =  month_data['beginning_month'].shift(-1)
+                month_data = month_data[month_data['ending_month']]
+                month_data.to_excel(writer, sheet_name='monthly')
                 writer.save()
             ################ computing the metrics per epoch (monthly !)
 
@@ -813,8 +819,6 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
                 'calmar': 'epoch realized calmar ratio',
                 'mdd': 'epoch realized max drawdown'})
 
-            epochkpis_df['epoch compounded return'] = np.cumprod(1. + epochkpis_df['epoch realized return'].values)
-
             epochkpis_df['epoch realized return'] = epochkpis_df['epoch realized return']*100.
             epochkpis_df['epoch realized annualized volatility'] = epochkpis_df['epoch realized annualized volatility']*100.
             epochkpis_df['epoch realized max drawdown'] = epochkpis_df['epoch realized max drawdown']*100.
